Structs
- Agent
Task Usage - AgentTaskUsage : Free-trial agent-task gate.
allowedis the only field clients must check before issuing a turn. Paid users getpaid: true, allowed: truewith the count fields null.
allowed is the only field clients must check before issuing a turn. Paid users get paid: true, allowed: true with the count fields null.