pub struct ReplyEmailRequest {
pub account_id: Option<String>,
pub to: Option<Vec<String>>,
pub cc: Option<Vec<String>>,
pub bcc: Option<Vec<String>>,
pub body: String,
pub html: Option<bool>,
pub attachments: Option<Vec<AttachmentInput>>,
}Expand description
ReplyEmailRequest : Reply to a specific email. to/cc/bcc are optional — the platform falls back to the original sender / recipients when omitted.
Fields
account_id: Option<String>to: Option<Vec<String>>cc: Option<Vec<String>>bcc: Option<Vec<String>>body: Stringhtml: Option<bool>attachments: Option<Vec<AttachmentInput>>Implementations
Sourceimpl ReplyEmailRequest
impl ReplyEmailRequest
Sourcepub fn new(body: String) -> ReplyEmailRequest
pub fn new(body: String) -> ReplyEmailRequest
Reply to a specific email. to/cc/bcc are optional — the platform falls back to the original sender / recipients when omitted.